Create a heatmap showing changes in communication between conditions.
Usage
PlotDiffHeatmap(
x,
metric = c("log2fc", "delta"),
cluster_order = NULL,
colors = NULL,
title = NULL,
...
)Create a heatmap showing changes in communication between conditions.
PlotDiffHeatmap(
x,
metric = c("log2fc", "delta"),
cluster_order = NULL,
colors = NULL,
title = NULL,
...
)